Class: GitLab::SecretDetection::Core::Status

Inherits:
Object
  • Object
show all
Defined in:
lib/gitlab/secret_detection/core/status.rb

Overview

All the possible statuses emitted by the scan operation

Constant Summary collapse

FOUND =

When scan operation completes with one or more findings

1
FOUND_WITH_ERRORS =

When scan operation completes with one or more findings along with some errors

2
SCAN_TIMEOUT =

When the scan operation runs beyond given time out

3
PAYLOAD_TIMEOUT =

When the scan operation on a payload runs beyond given time out

4
SCAN_ERROR =

When the scan operation fails due to regex error

5
INPUT_ERROR =

When the scan operation fails due to invalid input

6
NOT_FOUND =

When scan operation completes with zero findings

7