Class: Gitlab::SecretDetection::Gem
- Inherits:
-
Object
- Object
- Gitlab::SecretDetection::Gem
- Defined in:
- lib/gitlab/secret_detection/version.rb
Constant Summary collapse
- VERSION =
Ensure to maintain the same version in CHANGELOG file. More details available under ‘Release Process’ section in the README.md file.
"0.28.0"
Class Method Summary collapse
-
.local_env? ⇒ Boolean
SD_ENV env var is used to determine which environment the server is running.
Class Method Details
.local_env? ⇒ Boolean
SD_ENV env var is used to determine which environment the server is running. This var is defined in ‘.runway/env-<env>.yml` files.
12 13 14 |
# File 'lib/gitlab/secret_detection/version.rb', line 12 def self.local_env? ENV.fetch('SD_ENV', 'localhost') == 'localhost' end |