Class: Gitlab::SecretDetection::Gem

Inherits:
Object
  • Object
show all
Defined in:
lib/gitlab/secret_detection/version.rb

Constant Summary collapse

VERSION =

TODO: This is a temporary fix to avoid runtime issues More details are available here:

https://gitlab.com/gitlab-org/gitlab/-/issues/514015

Ensure to maintain the same version in CHANGELOG file.

"0.19.1"

Class Method Summary collapse

Class Method Details

.local_env?Boolean

SD_ENV env var is used to determine which environment the server is running. This var is defined in ‘.runway/env-<env>.yml` files.

Returns:

  • (Boolean)


15
16
17
# File 'lib/gitlab/secret_detection/version.rb', line 15

def self.local_env?
  ENV.fetch('SD_ENV', 'localhost') == 'localhost'
end